@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +20,25 @@
 #define AUDIOEQUALIZERLIST_H
 
 #include <QList>
+#include <QStringList>
 #include <QVariant>
 
+#define SIMPLE_EQUALIZER
+
 typedef QList<QVariant> AudioEqualizerList;
 
+class AudioEqualizerHelper {
+
+public:
+	enum AudioEqualizerType { Equalizer = 0, Anequalizer = 1, Firequalizer = 2, Superequalizer = 3, FEqualizer = 4 };
+
+	//! Returns a string to be passed to mplayer/mpv with the audio equalizer values.
+	static QString equalizerListToString(AudioEqualizerList values, AudioEqualizerType type = Equalizer);
+
+#ifndef SIMPLE_EQUALIZER
+	static QStringList equalizerListToStringList(AudioEqualizerList values, AudioEqualizerType type);
+	static QStringList equalizerListForCommand(AudioEqualizerList values, AudioEqualizerList old_values, AudioEqualizerType type);
+#endif
+};
+
 #endif
