@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1142,8 +1142,8 @@ void BaseGuiPlus::playOnChromecast() {
 	else
 	if (core->mdat.type == TYPE_FILE) {
 		QString subtitle;
-		if (MediaSettings::SubNone != core->mset.current_sub_id && MediaSettings::NoneSelected != core->mset.current_sub_id) {
-			SubData sub = core->mdat.subs.itemAt(core->mset.current_sub_id);
+		if (MediaSettings::SubNone != core->mset.current_subtitle_track && MediaSettings::NoneSelected != core->mset.current_subtitle_track) {
+			SubData sub = core->mset.subs.itemAt(core->mset.current_subtitle_track);
 			qDebug() << "BaseGuiPlus::playOnChromecast: current sub name:" << sub.name() << "filename:" << sub.filename();
 			if (!sub.filename().isEmpty()) subtitle = sub.filename(); else subtitle = sub.name();
 		}
