@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,10 @@
 #include <QDebug>
 #include "helper.h"
 
+#ifdef CONVERT_TO_VTT
+#include "subreader.h"
+#endif
+
 //#define CHROMECAST_USE_SERVER_WEBFSD
 //#define CHROMECAST_USE_SERVER_SIMPLE_WEB_SERVER
 
@@ -60,6 +64,13 @@ Chromecast::Chromecast(QObject * parent)
 	, directory_listing(true)
 	, server_needs_restart(false)
 {
+#ifdef CONVERT_TO_VTT
+	autoconvert_to_vtt = true;
+	sub_encoding = "ISO-8859-1";
+	sub_position = -1;
+	overwrite_vtt = false;
+	use_sub_filter = true;
+#endif
 }
 
 Chromecast::~Chromecast() {
@@ -93,7 +104,7 @@ void Chromecast::openLocal(const QString & file, const QString & title, const QS
 	QString sub_filename;
 	if (!subtitle.isEmpty()) {
 		// Check if subtitle is in the video directory
-		if (QFile::exists(dir +"/" + subtitle)) {
+		if (QFile::exists(dir +"/"+ subtitle)) {
 			sub_filename = subtitle;
 			qDebug() << "Chromecast::openLocal: sub_filename:" << sub_filename;
 		} else {
@@ -105,6 +116,7 @@ void Chromecast::openLocal(const QString & file, const QString & title, const QS
 				}
 			}
 		}
+		sub_filename = checkForVTT(dir, sub_filename);
 		qDebug() << "Chromecast::openLocal: sub_filename:" << sub_filename;
 	}
 #else
@@ -113,8 +125,8 @@ void Chromecast::openLocal(const QString & file, const QString & title, const QS
 		if (QFile::exists(subtitle)) {
 			sub_filepath = subtitle;
 		} else {
-			if (QFile::exists(dir +"/" + subtitle)) {
-				sub_filepath = dir +"/" + subtitle;
+			if (QFile::exists(dir +"/"+ subtitle)) {
+				sub_filepath = dir +"/"+ subtitle;
 			}
 		}
 		qDebug() << "Chromecast::openLocal: sub_filepath:" << sub_filepath;
@@ -166,6 +178,42 @@ QString Chromecast::filepathWithoutRoot(const QString & filepath) {
 }
 #endif
 
+QString Chromecast::checkForVTT(const QString & video_path, const QString & subtitle_file) {
+	QString actual_subtitle = subtitle_file;
+	QString dir = video_path;
+
+	QString subtitle_path = dir +"/"+ subtitle_file;
+	QFileInfo fi(subtitle_path);
+	if (fi.suffix().toLower() == "srt") {
+		qDebug() << "Chromecast::checkForVTT: subtitle is in srt format";
+
+		#ifdef CONVERT_TO_VTT
+		if (autoconvert_to_vtt) {
+			SubReader sr;
+			sr.setInputCodec(sub_encoding.toLatin1());
+			sr.setVTTLinePosition(sub_position);
+			if (use_sub_filter) {
+				QString filter = sub_filter;
+				if (filter.isEmpty()) filter = "opensubtitles|subtitulos\\.es|tusubtitulo|osdb|addic7ed";
+				sr.setTextFilter(filter);
+			}
+			sr.setOverwriteVTT(overwrite_vtt);
+			sr.autoConvertToVTT(subtitle_path);
+		}
+		#endif
+
+		// Check if a subtitle file with vtt extension exists
+		QString vtt_subtitle = fi.completeBaseName() + ".vtt";
+		QString vtt_subtitle_path = dir +"/"+ vtt_subtitle;
+		if (QFile::exists(vtt_subtitle_path)) {
+			qDebug() << "Chromecast::checkForVTT: using" << vtt_subtitle;
+			actual_subtitle = vtt_subtitle;
+		}
+	}
+
+	return actual_subtitle;
+}
+
 QStringList Chromecast::localAddresses() {
 	QStringList l;
 
@@ -292,6 +340,17 @@ void Chromecast::loadSettings() {
 		setLocalAddress(settings->value("local_address", localAddress()).toString());
 		setDirectoryListing(settings->value("directory_listing", directoryListing()).toBool());
 		settings->endGroup();
+
+		#ifdef CONVERT_TO_VTT
+		settings->beginGroup("chromecast/subtitles");
+		setAutoConvertToVTT(settings->value("autoconvert_to_vtt", autoConvertToVTT()).toBool());
+		//setSubtitleEncoding(settings->value("encoding", subtitleEncoding()).toString());
+		setSubtitlePosition(settings->value("position_on_screen", 93).toInt());
+		setSubtitleFilter(settings->value("text_filter", subtitleFilter()).toString());
+		setOverwriteVTT(settings->value("overwrite_vtt", overwriteVTT()).toBool());
+		enableSubtitleFilter(settings->value("use_sub_filter", isSubtitleFilterEnabled()).toBool());
+		settings->endGroup();
+		#endif
 	}
 }
 
@@ -304,6 +363,17 @@ void Chromecast::saveSettings() {
 		settings->setValue("local_address", localAddress());
 		settings->setValue("directory_listing", directoryListing());
 		settings->endGroup();
+
+		#ifdef CONVERT_TO_VTT
+		settings->beginGroup("chromecast/subtitles");
+		settings->setValue("autoconvert_to_vtt", autoConvertToVTT());
+		//settings->setValue("encoding", subtitleEncoding());
+		settings->setValue("position_on_screen", subtitlePosition());
+		settings->setValue("text_filter", subtitleFilter());
+		settings->setValue("overwrite_vtt", overwriteVTT());
+		settings->setValue("use_sub_filter", isSubtitleFilterEnabled());
+		settings->endGroup();
+		#endif
 	}
 }
 
