@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,12 +26,19 @@ class FindSubtitlesConfigDialog : public QDialog, public Ui::FindSubtitlesConfig
 	Q_OBJECT
 
 public:
+	enum SearchMethod { Hash = 0, Filename = 1 };
+
 	FindSubtitlesConfigDialog( QWidget* parent = 0, Qt::WindowFlags f = 0 );
 	~FindSubtitlesConfigDialog();
 
+#ifdef FS_USE_SERVER_CONFIG
 	// Server
 	void setServer(QString server);
 	QString server();
+#endif
+
+	void setSearchMethod(SearchMethod m);
+	int searchMethod();
 
 #ifdef OS_SEARCH_WORKAROUND
 	void setRetries(int n);
