@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -150,7 +150,7 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 	connect( osclient, SIGNAL(errorFound(int, const QString &)), this, SLOT(showErrorOS(int, const QString &)) );
 
 #ifdef DOWNLOAD_SUBS
-	include_lang_on_filename = true;
+	include_lang_on_filename = false;
 
 	file_downloader = new FileDownloader(this);
 	file_downloader->setModal(false);
@@ -186,6 +186,8 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 	os_server = "http://api.opensubtitles.org/xml-rpc";
 	osclient->setServer(os_server);
 
+	search_method = FindSubtitlesConfigDialog::Hash;
+
 #ifdef FS_USE_PROXY
 	// Proxy
 	use_proxy = false;
@@ -288,6 +290,9 @@ void FindSubtitlesWindow::retranslateStrings() {
 	downloadAct->setIcon( Images::icon("download") );
 	copyLinkAct->setIcon( Images::icon("copy") );
 #endif
+
+	credits_label->setText("<i>"+ tr("Subtitles service powered by %1")
+                           .arg("<a href=\"http://www.opensubtitles.org\">www.OpenSubtitles.org</a>") + "</i>");
 }
 
 void FindSubtitlesWindow::setMovie(QString filename) {
@@ -304,8 +309,13 @@ void FindSubtitlesWindow::setMovie(QString filename) {
 	if (hash.isEmpty()) {
 		qWarning("FindSubtitlesWindow::setMovie: hash invalid. Doing nothing.");
 	} else {
-		qint64 file_size = QFileInfo(filename).size();
-		osclient->search(hash, file_size);
+		QFileInfo fi(filename);
+		qint64 file_size = fi.size();
+		QString basename;
+		if (search_method == FindSubtitlesConfigDialog::Filename) {
+			basename = fi.completeBaseName(); // Filename without extension
+		}
+		osclient->search(hash, file_size, basename);
 		last_file = filename;
 	}
 }
@@ -775,7 +785,10 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 
 	FindSubtitlesConfigDialog d(this);
 
+	#ifdef FS_USE_SERVER_CONFIG
 	d.setServer( os_server );
+	#endif
+	d.setSearchMethod( (FindSubtitlesConfigDialog::SearchMethod) search_method );
 	#ifdef OS_SEARCH_WORKAROUND
 	d.setRetries(osclient->retries());
 	#endif
@@ -793,7 +806,10 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 	#endif
 
 	if (d.exec() == QDialog::Accepted) {
+		#ifdef FS_USE_SERVER_CONFIG
 		os_server = d.server();
+		#endif
+		search_method = d.searchMethod();
 		#ifdef OS_SEARCH_WORKAROUND
 		osclient->setRetries( d.retries() );
 		#endif
@@ -865,6 +881,8 @@ void FindSubtitlesWindow::saveSettings() {
 	set->setValue("proxy/password", proxy_password);
 #endif
 
+	set->setValue("search_method", search_method);
+
 	set->endGroup();
 }
 
@@ -892,6 +910,8 @@ void FindSubtitlesWindow::loadSettings() {
 	proxy_password = set->value("proxy/password", proxy_password).toString();
 #endif
 
+	search_method = set->value("search_method", search_method).toInt();
+
 	set->endGroup();
 }
 
