@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,10 +62,6 @@ public:
     //! If version is 4.3.2 it returns 40302.
 	static int qtVersion();
 
-	//! Returns a string to be passed to mplayer with the audio equalizer
-	//! values.
-	static QString equalizerListToString(AudioEqualizerList values, bool anequalizer_format = false);
-
 	static QStringList filesForPlaylist(const QString & initial_file, Preferences::AutoAddToPlaylistFilter filter);
 
 #ifdef Q_OS_WIN
