@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ InfoFile::InfoFile(QObject * parent)
 InfoFile::~InfoFile() {
 }
 
-QString InfoFile::getInfo(MediaData md) {
+QString InfoFile::getInfo(MediaData md, Tracks videos, Tracks audios, SubTracks subs) {
 	QString s;
 
 	// General
@@ -145,45 +145,45 @@ QString InfoFile::getInfo(MediaData md) {
 	s += closePar();
 
 	// Audio Tracks
-	if (md.audios.numItems() > 0) {
+	if (audios.numItems() > 0) {
 		s += openPar( tr("Audio Streams") );
 		s += addTrackColumns( QStringList() << "#" << tr("Language") << tr("Name") << "ID" );
 
-		for (int n = 0; n < md.audios.numItems(); n++) {
+		for (int n = 0; n < audios.numItems(); n++) {
 			#ifndef INFO_SIMPLE_LAYOUT
 			row++;
 			#endif
 			s += openItem();
-			QString lang = md.audios.itemAt(n).lang();
+			QString lang = audios.itemAt(n).lang();
 			if (lang.isEmpty()) lang = "<i>&lt;"+tr("undefined")+"&gt;</i>";
-			QString name = md.audios.itemAt(n).name();
+			QString name = audios.itemAt(n).name();
 			if (name.isEmpty()) name = "<i>&lt;"+tr("undefined")+"&gt;</i>";
-			s += addTrack(n, lang, name, md.audios.itemAt(n).ID());
+			s += addTrack(n, lang, name, audios.itemAt(n).ID());
 			s += closeItem();
 		}
 		s += closePar();
 	}
 
 	// Subtitles
-	if (md.subs.numItems() > 0) {
+	if (subs.numItems() > 0) {
 		s += openPar( tr("Subtitles") );
 		s += addTrackColumns( QStringList() << "#" << tr("Type") << tr("Language") << tr("Name") << "ID" );
-		for (int n = 0; n < md.subs.numItems(); n++) {
+		for (int n = 0; n < subs.numItems(); n++) {
 			#ifndef INFO_SIMPLE_LAYOUT
 			row++;
 			#endif
 			s += openItem();
 			QString t;
-			switch (md.subs.itemAt(n).type()) {
+			switch (subs.itemAt(n).type()) {
 				case SubData::File: t = "FILE_SUB"; break;
 				case SubData::Vob:	t = "VOB"; break;
 				default:			t = "SUB";
 			}
-			QString lang = md.subs.itemAt(n).lang();
+			QString lang = subs.itemAt(n).lang();
 			if (lang.isEmpty()) lang = "<i>&lt;"+tr("undefined")+"&gt;</i>";
-			QString name = md.subs.itemAt(n).name();
+			QString name = subs.itemAt(n).name();
 			if (name.isEmpty()) name = "<i>&lt;"+tr("undefined")+"&gt;</i>";
-			s += addTrack(n, lang, name, md.subs.itemAt(n).ID(), t);
+			s += addTrack(n, lang, name, subs.itemAt(n).ID(), t);
 			s += closeItem();
 		}
 		s += closePar();
