@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 #define INFO_SIMPLE_LAYOUT
 
 #include "mediadata.h"
+#include "tracks.h"
+#include "subtracks.h"
 #include <QString>
 
 class InfoFile : public QObject
@@ -32,7 +34,7 @@ public:
 	InfoFile(QObject * parent = 0);
 	~InfoFile();
 
-	QString getInfo(MediaData md);
+	QString getInfo(MediaData md, Tracks videos, Tracks audios, SubTracks subs);
 
 protected:
 	QString title(QString text, QString icon);
