@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 LineEditWithIcon::LineEditWithIcon(QWidget *parent) : QLineEdit(parent)
 {
-    button = new QToolButton(this);
+	button = new QToolButton(this);
 	button->setCursor(Qt::ArrowCursor);
 	setupButton();
 }
@@ -35,7 +35,7 @@ void LineEditWithIcon::setIcon(const QPixmap & pixmap) {
 	QPixmap p = pixmap;
 	//qDebug("height: %d, icon height: %d", height(), p.height());
 	int max_height = 16;
-	if (max_height > height()) max_height = height() - 4;
+	if (max_height > height() && height() >= 8) max_height = height() - 4;
 	if (pixmap.height() > max_height) p = pixmap.scaledToHeight(max_height, Qt::SmoothTransformation);
 	button->setIcon(p);
 	button->setStyleSheet("QToolButton { border: none; padding: 0px; }");
@@ -50,11 +50,10 @@ void LineEditWithIcon::setIcon(const QPixmap & pixmap) {
     */
 }
 
-void LineEditWithIcon::resizeEvent(QResizeEvent *)
-{
-    QSize sz = button->sizeHint();
-    int frameWidth = style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
-    button->move(rect().right() - frameWidth - sz.width(),
+void LineEditWithIcon::resizeEvent(QResizeEvent *) {
+	QSize sz = button->sizeHint();
+	int frameWidth = style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
+	button->move(rect().right() - frameWidth - sz.width(),
                  (rect().bottom() + 1 - sz.height())/2);
 }
 
@@ -63,7 +62,7 @@ void LineEditWithIcon::changeEvent(QEvent *e) {
 	if (e->type() == QEvent::LanguageChange) {
 		setupButton();
 	} else {
-		QWidget::changeEvent(e);
+		QLineEdit::changeEvent(e);
 	}
 }
 
