@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,10 +34,11 @@ void MediaSettings::reset() {
 	qDebug("MediaSettings::reset");
 
 	current_sec = 0;
-	//current_sub_id = SubNone; 
-	current_sub_id = NoneSelected;
+
+	//current_subtitle_track = SubNone;
+	current_subtitle_track = NoneSelected;
 #ifdef MPV_SUPPORT
-	current_secondary_sub_id = NoneSelected;
+	current_secondary_subtitle_track = NoneSelected;
 #endif
 #if PROGRAM_SWITCH
 	current_program_id = NoneSelected;
@@ -147,6 +148,10 @@ void MediaSettings::reset() {
 
 	win_width=400;
 	win_height=300;
+
+	videos.clear();
+	audios.clear();
+	subs.clear();
 }
 
 double MediaSettings::win_aspect() {
@@ -202,9 +207,9 @@ void MediaSettings::list() {
 	qDebug("MediaSettings::list");
 
 	qDebug("  current_sec: %f", current_sec);
-	qDebug("  current_sub_id: %d", current_sub_id);
+	qDebug("  current_subtitle_track: %d", current_subtitle_track);
 #ifdef MPV_SUPPORT
-	qDebug("  current_secondary_sub_id: %d", current_secondary_sub_id);
+	qDebug("  current_secondary_subtitle_track: %d", current_secondary_subtitle_track);
 #endif
 #if PROGRAM_SWITCH
 	qDebug("  current_program_id: %d", current_program_id);
@@ -299,6 +304,15 @@ void MediaSettings::list() {
 #endif
 
 	qDebug("  is264andHD: %d", is264andHD);
+
+	qDebug("  Videos:");
+	videos.list();
+
+	qDebug("  Audios:");
+	audios.list();
+
+	qDebug("  Subtitles:");
+	subs.list();
 }
 
 void MediaSettings::save(QSettings * set, int player_id) {
@@ -325,9 +339,9 @@ void MediaSettings::save(QSettings * set, int player_id) {
 #endif
 
 	set->beginGroup(demuxer_section);
-	set->setValue( "current_sub_id", current_sub_id );
+	set->setValue( "current_subtitle_track", current_subtitle_track );
 	#ifdef MPV_SUPPORT
-	set->setValue( "current_secondary_sub_id", current_secondary_sub_id );
+	set->setValue( "current_secondary_subtitle_track", current_secondary_subtitle_track );
 	#endif
 	#if PROGRAM_SWITCH
 	set->setValue( "current_program_id", current_program_id );
@@ -436,6 +450,11 @@ void MediaSettings::save(QSettings * set, int player_id) {
 #endif
 
 	set->setValue( "is264andHD", is264andHD );
+
+	// Save tracks
+	videos.save(set, "videotracks");
+	audios.save(set, "audiotracks");
+	subs.save(set, "subtitletracks");
 }
 
 void MediaSettings::load(QSettings * set, int player_id) {
@@ -464,9 +483,9 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	qDebug("MediaSettings::load: demuxer_section: %s", demuxer_section.toUtf8().constData());
 
 	set->beginGroup(demuxer_section);
-	current_sub_id = set->value( "current_sub_id", NoneSelected ).toInt();
+	current_subtitle_track = set->value( "current_subtitle_track", NoneSelected ).toInt();
 	#ifdef MPV_SUPPORT
-	current_secondary_sub_id = set->value( "current_secondary_sub_id", NoneSelected ).toInt();
+	current_secondary_subtitle_track = set->value( "current_secondary_subtitle_track", NoneSelected ).toInt();
 	#endif
 	#if PROGRAM_SWITCH
 	current_program_id = set->value( "current_program_id", NoneSelected ).toInt();
@@ -575,5 +594,19 @@ void MediaSettings::load(QSettings * set, int player_id) {
 
 	// ChDefault not used anymore
 	//if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
+
+	// Load tracks
+	videos.load(set, "videotracks");
+	audios.load(set, "audiotracks");
+	subs.load(set, "subtitletracks");
+
+	qDebug("MediaSettings::load: list of video tracks:");
+	videos.list();
+
+	qDebug("MediaSettings::load: list of audio tracks:");
+	audios.list();
+
+	qDebug("MediaSettings::load: list of subtitle tracks:");
+	subs.list();
 }
 
