@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@
 #include <QDir>
 #include <QDebug>
 
+void MplayerProcess::initializeOptionVars() {
+	qDebug("MplayerProcess::initializeOptionVars");
+	PlayerProcess::initializeOptionVars();
+}
+
 void MplayerProcess::setMedia(const QString & media, bool is_playlist) {
 	if (is_playlist) arg << "-playlist";
 	arg << media;
@@ -117,6 +122,20 @@ void MplayerProcess::setOption(const QString & option_name, const QVariant & val
 		if (o.contains("decoder")) arg << "-hardframedrop";
 	}
 	else
+	if (option_name == "osd-level") {
+		arg << "-osdlevel" << value.toString();
+	}
+	else
+	if (option_name == "osd-fractions") {
+	}
+	else
+	if (option_name == "osd-bar-pos") {
+		int position = value.toInt();
+		if (position >= 0 && position <= 100) {
+			arg << "-progbar-align" << QString::number(position);
+		}
+	}
+	else
 	if (option_name == "osd-scale") {
 		arg << "-subfont-osd-scale" << value.toString();
 	}
@@ -371,12 +390,16 @@ void MplayerProcess::showOSDText(const QString & text, int duration, int level)
 	writeToStdin(str);
 }
 
-void MplayerProcess::showFilenameOnOSD() {
+void MplayerProcess::showFilenameOnOSD(int duration) {
 	QString s = "${filename}";
 
 	if (!osd_media_info.isEmpty()) s = osd_media_info;
 
-	writeToStdin("osd_show_property_text \"" + s + "\" 2000 0");
+	writeToStdin(QString("osd_show_property_text \"%1\" %2 0").arg(s).arg(duration));
+}
+
+void MplayerProcess::showMediaInfoOnOSD() {
+	showFilenameOnOSD();
 }
 
 void MplayerProcess::showTimeOnOSD() {
