@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,10 +40,25 @@
 #define USE_LETTERBOX LETTERBOX_PAD
 #endif
 
+#define OSD_PREFIX use_osd_in_commands ? "" : "no-osd"
+//#define OSD_PREFIX ""
 
 void MPVProcess::addArgument(const QString & /*a*/) {
 }
 
+void MPVProcess::initializeOptionVars() {
+	qDebug("MPVProcess::initializeOptionVars");
+	PlayerProcess::initializeOptionVars();
+
+#ifdef OSD_WITH_TIMER
+	osd_timer = new QTimer(this);
+	osd_timer->setInterval(500);
+	connect(osd_timer, SIGNAL(timeout()), this, SLOT(displayInfoOnOSD()));
+#endif
+
+	use_osd_in_commands = true;
+}
+
 void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 	arg << "--term-playing-msg="
 			"MPV_VERSION=${=mpv-version:}\n"
@@ -102,13 +117,6 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 	capturing = false;
 #endif
 
-#ifdef OSD_WITH_TIMER
-	if (!osd_timer) {
-		osd_timer = new QTimer(this);
-		osd_timer->setInterval(500);
-		connect(osd_timer, SIGNAL(timeout()), this, SLOT(displayInfoOnOSD()));
-	}
-#endif
 }
 
 void MPVProcess::setFixedOptions() {
@@ -119,6 +127,7 @@ void MPVProcess::setFixedOptions() {
 	arg << "--input-file=/dev/stdin";
 	//arg << "--no-osc";
 	//arg << "--msg-level=vd=v";
+	//arg << "--video-stereo-mode=no";
 }
 
 void MPVProcess::disableInput() {
@@ -264,10 +273,24 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		arg << "--sub-codepage=" + cp;
 	}
 	else
-	if (option_name == "osdlevel") {
+	if (option_name == "osd-level") {
 		arg << "--osd-level=" + value.toString();
 	}
 	else
+	if (option_name == "osd-fractions") {
+		bool use_fractions = value.toBool();
+		if (use_fractions) arg << "--osd-fractions";
+	}
+	else
+	if (option_name == "osd-bar-pos") {
+		if (isOptionAvailable("--osd-bar-align-y")) {
+			if (value.toInt() >= 0 && value.toInt() <= 100) {
+				double position = double (value.toInt() * 2 - 100) / 100;
+				arg << "--osd-bar-align-y=" + QString::number(position);
+			}
+		}
+	}
+	else
 	if (option_name == "sws") {
 		arg << "--sws-scaler=lanczos";
 	}
@@ -495,8 +518,13 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		if (!value.isNull()) arg << "--af-add=" + value.toString();
 	}
 	else
+	if (option_name == "aid" || option_name == "sid" || option_name == "secondary-sid" || option_name == "vid") {
+		int v = value.toInt();
+		arg << QString("--%1=%2").arg(option_name).arg(v > -1 ? value.toString() : "no");
+	}
+	else
 	if (option_name == "wid" ||
-	    option_name == "aid" || option_name == "vid" ||
+	    option_name == "alang" || option_name == "slang" ||
 	    option_name == "volume" ||
 	    option_name == "ass-styles" ||
 	    option_name == "embeddedfonts" ||
@@ -677,31 +705,32 @@ void MPVProcess::setOSD(int o) {
 }
 
 void MPVProcess::setAudio(int ID) {
-	writeToStdin("set aid " + QString::number(ID));
+	writeToStdin(QString("%1 set aid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::setVideo(int ID) {
-	writeToStdin("set vid " + QString::number(ID));
+	writeToStdin(QString("%1 set vid %2").arg(OSD_PREFIX).arg(ID));
 }
 
-void MPVProcess::setSubtitle(int /*type*/, int ID) {
-	writeToStdin("set sid " + QString::number(ID));
+void MPVProcess::setSubtitle(int type, int ID) {
+	Q_UNUSED(type);
+	writeToStdin(QString("%1 set sid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::disableSubtitles() {
-	writeToStdin("set sid no");
+	writeToStdin("no-osd set sid no");
 }
 
 void MPVProcess::setSecondarySubtitle(int ID) {
-	writeToStdin("set secondary-sid " + QString::number(ID));
+	writeToStdin(QString("%1 set secondary-sid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::disableSecondarySubtitles() {
-	writeToStdin("set secondary-sid no");
+	writeToStdin("no-osd set secondary-sid no");
 }
 
 void MPVProcess::setSubtitlesVisibility(bool b) {
-	writeToStdin(QString("set sub-visibility %1").arg(b ? "yes" : "no"));
+	writeToStdin(QString("no-osd set sub-visibility %1").arg(b ? "yes" : "no"));
 }
 
 void MPVProcess::seek(double secs, int mode, bool precise) {
@@ -732,11 +761,20 @@ void MPVProcess::frameBackStep() {
 }
 
 void MPVProcess::showOSDText(const QString & text, int duration, int level) {
-	QString str = QString("show_text \"%1\" %2 %3").arg(text).arg(duration).arg(level);
-	writeToStdin(str);
+	if (use_osd_in_commands) {
+		QString str = QString("show_text \"%1\" %2 %3").arg(text).arg(duration).arg(level);
+		writeToStdin(str);
+	}
 }
 
-void MPVProcess::showFilenameOnOSD() {
+void MPVProcess::showFilenameOnOSD(int duration) {
+#ifdef OSD_WITH_TIMER
+	osd_timer->stop();
+#endif
+	showOSDText("${filename}", duration, 0);
+}
+
+void MPVProcess::showMediaInfoOnOSD() {
 #ifdef OSD_WITH_TIMER
 	toggleInfoOnOSD();
 #else
@@ -1155,10 +1193,10 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 		arg << sub_color + "=#" + ColorUtils::colorToAARRGGBB(styles.primarycolor);
 	}
 
-	if (styles.borderstyle == AssStyles::Outline) {
-		arg << sub_shadow_color + "=#" + ColorUtils::colorToAARRGGBB(styles.backcolor);
-	} else {
-		arg << sub_back_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
+	arg << sub_shadow_color + "=#" + ColorUtils::colorToAARRGGBB(styles.backcolor);
+
+	if (styles.borderstyle == AssStyles::Opaque) {
+		arg << sub_back_color + "=#" + ColorUtils::colorToAARRGGBB(styles.backgroundcolor);
 	}
 
 	if (!sub_border_color.isEmpty()) {
