@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,8 +35,8 @@ MyApplication::MyApplication (const QString & /*appId*/, int & argc, char ** arg
 	setFallbackSessionManagementEnabled(false);
 #endif
 #if QT_VERSION >= 0x050000
-	connect(this, SIGNAL(commitDataRequest(QSessionManager)),
-            this, SLOT(commitData(QSessionManager)));
+	connect(this, SIGNAL(commitDataRequest(QSessionManager &)),
+            this, SLOT(commitData(QSessionManager &)), Qt::DirectConnection);
 #endif
 };
 
