@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,7 +74,8 @@ public:
 	virtual void frameStep() = 0;
 	virtual void frameBackStep() = 0;
 	virtual void showOSDText(const QString & text, int duration, int level) = 0;
-	virtual void showFilenameOnOSD() = 0;
+	virtual void showFilenameOnOSD(int duration = 2000) = 0;
+	virtual void showMediaInfoOnOSD() = 0;
 	virtual void showTimeOnOSD() = 0;
 
 	virtual void setContrast(int value) = 0;
@@ -138,6 +139,9 @@ public:
 	void setOSDMediaInfo(const QString & s) { osd_media_info = s; };
 	QString OSDMediaInfo() { return osd_media_info; };
 
+	virtual void enableOSDInCommands(bool b) = 0;
+	virtual bool isOSDInCommandsEnabled() = 0;
+
 #ifdef CAPTURE_STREAM
 	virtual void setCaptureDirectory(const QString & dir);
 #endif
@@ -180,18 +184,18 @@ signals:
 
 #if NOTIFY_SUB_CHANGES
 	//! Emitted if a new subtitle has been added or an old one changed
-	void subtitleInfoChanged(const SubTracks &);
+	void subtitleInfoChanged(const SubTracks &, int selected_id);
 
 	//! Emitted when subtitle info has been received but there wasn't anything new
 	void subtitleInfoReceivedAgain(const SubTracks &);
 #endif
 #if NOTIFY_AUDIO_CHANGES
 	//! Emitted if a new audio track been added or an old one changed
-    void audioInfoChanged(const Tracks &);
+    void audioInfoChanged(const Tracks &, int selected_id);
 #endif
 #if NOTIFY_VIDEO_CHANGES
 	//! Emitted if a new video track been added or an old one changed
-	void videoInfoChanged(const Tracks &);
+	void videoInfoChanged(const Tracks &, int selected_id);
 #endif
 #if NOTIFY_CHAPTER_CHANGES
 	void chaptersChanged(const Chapters &);
@@ -208,6 +212,8 @@ signals:
 	void receivedAudioBitrate(int);
 
 protected:
+	virtual void initializeOptionVars() {};
+
 	MediaData md;
 	QString pausing_prefix;
 
