@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,9 +45,11 @@
 #include <QMimeData>
 #include <QDomDocument>
 #include <QDesktopServices>
+#include <QClipboard>
 #include <QDebug>
 
 #if QT_VERSION >= 0x050000
+#include <QUrlQuery>
 #include "myscroller.h"
 #endif
 
@@ -72,10 +74,13 @@
 #include "urlhistory.h"
 #include <QNetworkAccessManager>
 #include <QTemporaryFile>
-#include <QClipboard>
 #include <QMovie>
 #endif
 
+#if defined(YT_PLAYLIST_SUPPORT) && QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
+
 #if USE_INFOPROVIDER
 #include "infoprovider.h"
 #endif
@@ -244,6 +249,14 @@ QString PLItem::videoURL() {
 	return data(Role_Video_URL).toString();
 }
 
+void PLItem::setIconURL(const QString & url) {
+	setData(url, Role_Icon_URL);
+}
+
+QString PLItem::iconURL() {
+	return data(Role_Icon_URL).toString();
+}
+
 /* ----------------------------------------------------------- */
 
 
@@ -860,7 +873,7 @@ void Playlist::changeItem(int row, const QString & filename, const QString name,
 }
 */
 
-void Playlist::addItem(QString filename, QString name, double duration, QStringList params, QString video_url) {
+void Playlist::addItem(QString filename, QString name, double duration, QStringList params, QString video_url, QString icon_url) {
 	//qDebug() << "Playlist::addItem:" << filename;
 
 	#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
@@ -882,6 +895,7 @@ void Playlist::addItem(QString filename, QString name, double duration, QStringL
 	PLItem * i = new PLItem(filename, name, duration);
 	i->setExtraParams(params);
 	i->setVideoURL(video_url);
+	i->setIconURL(icon_url);
 	i->setPosition(count()+1);
 	table->appendRow(i->items());
 
@@ -941,7 +955,7 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 	qDebug() << "Playlist::load_m3u: utf8:" << utf8;
 
 	QRegExp m3u_id("^#EXTM3U|^#M3U");
-	QRegExp info("^#EXTINF:(.*),(.*)");
+	QRegExp rx_info("^#EXTINF:([.\\d]+).*tvg-logo=\"(.*)\",(.*)");
 
 	QFile f( file );
 	if ( f.open( QIODevice::ReadOnly ) ) {
@@ -952,6 +966,7 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 		QString name="";
 		double duration=0;
 		QStringList extra_params;
+		QString icon_url;
 
 		QTextStream stream( &f );
 
@@ -965,19 +980,19 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 			line = stream.readLine().trimmed();
 			if (line.isEmpty()) continue; // Ignore empty lines
 
-			qDebug( "Playlist::load_m3u: line: '%s'", line.toUtf8().data() );
+			qDebug() << "Playlist::load_m3u: line:" << line;
 			if (m3u_id.indexIn(line)!=-1) {
 				//#EXTM3U
 				// Ignore line
 			}
 			else
-			/*
-			if (info.indexIn(line)!=-1) {
-				duration = info.cap(1).toDouble();
-				name = info.cap(2);
-				qDebug("Playlist::load_m3u: name: '%s', duration: %f", name.toUtf8().data(), duration );
-			} 
-			*/
+			if (rx_info.indexIn(line) != -1) {
+				duration = rx_info.cap(1).toDouble();
+				name = rx_info.cap(3);
+				icon_url = rx_info.cap(2);
+				qDebug() << "Playlist::load_m3u: name:" << name << "duration:" << duration << "icon_url:" << icon_url;
+			}
+			else
 			if (line.startsWith("#EXTINF:")) {
 				QStringList fields = line.mid(8).split(",");
 				//qDebug() << "Playlist::load_m3u: fields:" << fields;
@@ -1007,10 +1022,11 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 				}
 				name.replace("&#44;", ",");
 				//qDebug() << "Playlist::load_m3u: extra_params:" << extra_params;
-				addItem( filename, name, duration, extra_params );
-				name=""; 
+				addItem( filename, name, duration, extra_params, "", icon_url );
+				name = "";
 				duration = 0;
 				extra_params.clear();
+				icon_url = "";
 			}
 		}
 		f.close();
@@ -1120,6 +1136,48 @@ void Playlist::loadXSPF(const QString & filename) {
 	}
 }
 
+#ifdef YT_PLAYLIST_SUPPORT
+/// youtube list support
+void Playlist::loadYoutubeList(QByteArray & data) {
+	qDebug() << "Playlist::loadYoutubeList:";
+
+	QDomDocument dom_document;
+	bool ok = dom_document.setContent(data);
+	qDebug() << "Playlist::loadYoutubeList: success:" << ok;
+	if (!ok) return;
+
+	QDomNode root = dom_document.documentElement();
+	if (!root.isNull()) {
+		clear();
+
+		QDomNode track = root.firstChildElement("video");
+		while (!track.isNull()) {
+			QString filename;
+			QStringList extra_params;
+
+			QString title = track.firstChildElement("title").text(); // toCDATASection().data();
+			QString video_url = QString("https://www.youtube.com/watch?v=").append(track.firstChildElement("encrypted_id").text().toLatin1());
+			QString icon_url  = track.firstChildElement("thumbnail").text().toLatin1();
+			int duration = track.firstChildElement("length_seconds").text().toInt();
+
+			qDebug() << "Playlist::loadYoutubeList: title:" << title;
+			qDebug() << "Playlist::loadYoutubeList: video_url:" << video_url;
+			qDebug() << "Playlist::loadYoutubeList: icon_url:" << icon_url;
+			qDebug() << "Playlist::loadYoutubeList: duration:" << duration;
+
+			addItem( video_url, title, duration, extra_params, video_url, icon_url );
+
+			track = track.nextSiblingElement("video");
+		}
+
+		//list();
+		setPlaylistFilename(root.firstChildElement("title").text());
+		setModified( false );
+		if (start_play_on_load) startPlay();
+	}
+}
+#endif
+
 bool Playlist::save_m3u(QString file) {
 	qDebug() << "Playlist::save_m3u:" << file;
 
@@ -1157,8 +1215,11 @@ bool Playlist::save_m3u(QString file) {
 			#endif
 			name = i->name();
 			name.replace(",", "&#44;");
+			QString icon_url = i->iconURL();
 			stream << "#EXTINF:";
-			stream << i->duration() << ",";
+			stream << i->duration();
+			if (!icon_url.isEmpty()) stream << " tvg-logo=\"" + icon_url + "\"";
+			stream << ",";
 			stream << name << "\n";
 
 			// Save extra params
@@ -1762,6 +1823,9 @@ void Playlist::removeSelected() {
 	QModelIndexList indexes = listView->selectionModel()->selectedRows();
 	int count = indexes.count();
 
+	qDebug() << "Playlist::removeSelected: count:" << count;
+	if (count < 1) return;
+
 	for (int n = count; n > 0; n--) {
 		QModelIndex s_index = proxy->mapToSource(indexes.at(n-1));
 		table->removeRow(s_index.row());
@@ -2201,6 +2265,7 @@ void Playlist::saveSettings() {
 			set->setValue( QString("item_%1_name").arg(n), i->name() );
 			set->setValue( QString("item_%1_params").arg(n), i->extraParams() );
 			set->setValue( QString("item_%1_video_url").arg(n), i->videoURL() );
+			set->setValue( QString("item_%1_icon_url").arg(n), i->iconURL() );
 		}
 		set->endArray();
 		set->setValue( "current_item", findCurrentItem() );
@@ -2285,7 +2350,8 @@ void Playlist::loadSettings() {
 			name = set->value( QString("item_%1_name").arg(n), "" ).toString();
 			QStringList params = set->value( QString("item_%1_params").arg(n), QStringList()).toStringList();
 			QString video_url = set->value( QString("item_%1_video_url").arg(n), "").toString();
-			addItem( filename, name, duration, params, video_url );
+			QString icon_url = set->value( QString("item_%1_icon_url").arg(n), "").toString();
+			addItem( filename, name, duration, params, video_url, icon_url );
 		}
 		set->endArray();
 		setCurrentItem( set->value( "current_item", -1 ).toInt() );
@@ -2387,10 +2453,26 @@ void Playlist::openUrl() {
 	}
 }
 
-void Playlist::openUrl(const QString & url) {
-	qDebug() << "Playlist::openUrl:" << url;
-	downloader->fetchPage(url);
+void Playlist::openUrl(const QString & orig_url) {
+	QString url = QString(orig_url);
 
+	qDebug() << "Playlist::openUrl:" << url;
+
+#ifdef YT_PLAYLIST_SUPPORT
+	// if youtube list then convert to ajax call
+	if (url.contains("youtube") && url.contains("list=")) {
+		QUrl qurl = QUrl(url);
+		#if QT_VERSION >= 0x050000
+		QUrlQuery query = QUrlQuery(qurl);
+		QString lst = query.queryItemValue("list"); // QString("RDQ4DphMfcOOM"); // todo
+		#else
+		QString lst = qurl.queryItemValue("list");
+		#endif
+		url = QString("https://www.youtube.com/list_ajax?action_get_list=1&style=xml&list=").append(lst);
+	}
+#endif
+
+	downloader->fetchPage(url);
 	showLoadingAnimation(true);
 }
 
@@ -2404,6 +2486,12 @@ void Playlist::playlistDownloaded(QByteArray data) {
 	QString tfile = tf.fileName();
 	qDebug() << "Playlist::playlistDownloaded: tfile:" << tfile;
 
+#ifdef YT_PLAYLIST_SUPPORT
+	if (data.contains("<?xml")) {
+		loadYoutubeList(data);
+	}
+	else
+#endif
 	if (data.contains("#EXTM3U")) {
 		load_m3u(tfile, M3U8);
 		setPlaylistFilename("");
