@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -116,8 +116,13 @@ void Preferences::reset() {
 	remember_time_pos = true;
 	remember_stream_settings = true;
 
+#if SIMPLE_TRACK_SELECTION
+	alang = "";
+	slang = "";
+#else
 	audio_lang = "";
 	subtitle_lang = "";
+#endif
 
 	use_direct_rendering = false;
 	use_double_buffer = true;
@@ -184,10 +189,12 @@ void Preferences::reset() {
 	osd = Seek;
 	osd_scale = 1;
 	subfont_osd_scale = 3;
-	osd_delay = 2200;
+	osd_delay = 5000;
 #ifdef MPV_SUPPORT
 	osd_fractions = false;
 #endif
+	osd_bar_pos = 80;
+	osd_show_filename_duration = 2000;
 
 	file_settings_method = "hash"; // Possible values: normal & hash
 
@@ -379,6 +386,10 @@ void Preferences::reset() {
 	mplayer_osd_media_info = "";
 #endif
 
+#ifdef MPV_SUPPORT
+	emulate_mplayer_ab_section = false;
+#endif
+
 
     /* *********
        GUI stuff
@@ -567,8 +578,10 @@ void Preferences::reset() {
 	initial_audio_channels = MediaSettings::ChDefault;
 	initial_stereo_mode = MediaSettings::Stereo;
 
-	initial_audio_track = 1;
-	initial_subtitle_track = 1;
+#if SELECT_TRACKS_ON_STARTUP
+	initial_audio_track = 0;
+	initial_subtitle_track = 0;
+#endif
 
 
     /* ************
@@ -668,8 +681,13 @@ void Preferences::save() {
 	set->setValue("remember_time_pos", remember_time_pos);
 	set->setValue("remember_stream_settings", remember_stream_settings);
 
+#if SIMPLE_TRACK_SELECTION
+	set->setValue("alang", alang);
+	set->setValue("slang", slang);
+#else
 	set->setValue("audio_lang", audio_lang);
 	set->setValue("subtitle_lang", subtitle_lang);
+#endif
 
 	set->setValue("use_direct_rendering", use_direct_rendering);
 	set->setValue("use_double_buffer", use_double_buffer);
@@ -731,6 +749,8 @@ void Preferences::save() {
 #ifdef MPV_SUPPORT
 	set->setValue("osd_fractions", osd_fractions);
 #endif
+	set->setValue("osd_bar_pos", osd_bar_pos);
+	set->setValue("osd_show_filename_duration", osd_show_filename_duration);
 
 	set->setValue("file_settings_method", file_settings_method);
 
@@ -918,6 +938,10 @@ void Preferences::save() {
 	set->setValue("mplayer_osd_media_info", mplayer_osd_media_info);
 #endif
 
+#ifdef MPV_SUPPORT
+	set->setValue("emulate_mplayer_ab_section", emulate_mplayer_ab_section);
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -1114,8 +1138,10 @@ void Preferences::save() {
 	set->setValue("audio_channels", initial_audio_channels);
 	set->setValue("initial_stereo_mode", initial_stereo_mode);
 
-	set->setValue("initial_audio_track", initial_audio_track);
-	set->setValue("initial_subtitle_track", initial_subtitle_track);
+#if SELECT_TRACKS_ON_STARTUP
+	set->setValue("preferred_audio_track", initial_audio_track);
+	set->setValue("preferred_subtitle_track", initial_subtitle_track);
+#endif
 
 	set->endGroup(); // defaults
 
@@ -1241,12 +1267,17 @@ void Preferences::load() {
 	remember_time_pos = set->value("remember_time_pos", remember_time_pos).toBool();
 	remember_stream_settings = set->value("remember_stream_settings", remember_stream_settings).toBool();
 
+#if SIMPLE_TRACK_SELECTION
+	alang = set->value("alang", alang).toString();
+	slang = set->value("slang", slang).toString();
+#else
 	audio_lang = set->value("audio_lang", audio_lang).toString();
 	subtitle_lang = set->value("subtitle_lang", subtitle_lang).toString();
+#endif
 
 	use_direct_rendering = set->value("use_direct_rendering", use_direct_rendering).toBool();
 	use_double_buffer = set->value("use_double_buffer", use_double_buffer).toBool();
-	
+
 	use_soft_video_eq = set->value("use_soft_video_eq", use_soft_video_eq).toBool();
 	use_slices = set->value("use_slices", use_slices ).toBool();
 	autoq = set->value("autoq", autoq).toInt();
@@ -1305,6 +1336,8 @@ void Preferences::load() {
 #ifdef MPV_SUPPORT
 	osd_fractions = set->value("osd_fractions", osd_fractions).toBool();
 #endif
+	osd_bar_pos = set->value("osd_bar_pos", osd_bar_pos).toInt();
+	osd_show_filename_duration = set->value("osd_show_filename_duration", osd_show_filename_duration).toInt();
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
 
@@ -1496,6 +1529,10 @@ void Preferences::load() {
 	mplayer_osd_media_info = set->value("mplayer_osd_media_info", mplayer_osd_media_info).toString();
 #endif
 
+#ifdef MPV_SUPPORT
+	emulate_mplayer_ab_section = set->value("emulate_mplayer_ab_section", emulate_mplayer_ab_section).toBool();
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -1692,8 +1729,10 @@ void Preferences::load() {
 	initial_audio_channels = set->value("audio_channels", initial_audio_channels).toInt();
 	initial_stereo_mode = set->value("initial_stereo_mode", initial_stereo_mode).toInt();
 
-	initial_audio_track = set->value("initial_audio_track", initial_audio_track).toInt();
-	initial_subtitle_track = set->value("initial_subtitle_track", initial_subtitle_track).toInt();
+#if SELECT_TRACKS_ON_STARTUP
+	initial_audio_track = set->value("preferred_audio_track", initial_audio_track).toInt();
+	initial_subtitle_track = set->value("preferred_subtitle_track", initial_subtitle_track).toInt();
+#endif
 
 	set->endGroup(); // defaults
 
