@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -104,6 +104,11 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	blackborders_check->hide();
 #endif
 
+#if !SELECT_TRACKS_ON_STARTUP
+	tracks_frame->hide();
+	tracks_separator->hide();
+#endif
+
 #ifdef MPV_SUPPORT
 	screenshot_format_combo->addItems(QStringList() << "png" << "ppm" << "pgm" << "pgmyuv" << "tga" << "jpg" << "jpeg");
 #else
@@ -206,9 +211,7 @@ void PrefGeneral::retranslateStrings() {
            "subtitle streams is found, SMPlayer will try to use your "
            "preferred language. This only will work with media that offer "
            "info about the language of audio and subtitle streams, like DVDs "
-           "or mkv files.<br>These fields accept regular expressions. "
-           "Example: <b>es|esp|spa</b> will select the track if it matches with "
-            "<i>es</i>, <i>esp</i> or <i>spa</i>."));
+           "or mkv files.") );
 
 #ifndef MPLAYER_MPV_SELECTION
 	executable_label->setText( tr("%1 &executable:").arg(PLAYER_NAME) );
@@ -235,10 +238,19 @@ void PrefGeneral::setData(Preferences * pref) {
 	remember_streams_check->setChecked(pref->remember_stream_settings);
 
 	setFileSettingsMethod( pref->file_settings_method );
+
+#if SIMPLE_TRACK_SELECTION
+	setAudioLang( pref->alang );
+	setSubtitleLang( pref->slang );
+#else
 	setAudioLang( pref->audio_lang );
 	setSubtitleLang( pref->subtitle_lang );
+#endif
+#if SELECT_TRACKS_ON_STARTUP
 	setAudioTrack( pref->initial_audio_track );
 	setSubtitleTrack( pref->initial_subtitle_track );
+#endif
+
 	setCloseOnFinish( pref->close_on_finish );
 	setPauseWhenHidden( pref->pause_when_hidden );
 #ifdef AUTO_SHUTDOWN_PC
@@ -333,11 +345,17 @@ void PrefGeneral::getData(Preferences * pref) {
 		filesettings_method_changed = true;
 	}
 
+#if SIMPLE_TRACK_SELECTION
+	pref->alang = audioLang();
+	pref->slang = subtitleLang();
+#else
 	pref->audio_lang = audioLang();
 	pref->subtitle_lang = subtitleLang();
-
+#endif
+#if SELECT_TRACKS_ON_STARTUP
 	pref->initial_audio_track = audioTrack();
 	pref->initial_subtitle_track = subtitleTrack();
+#endif
 
 	pref->close_on_finish = closeOnFinish();
 	pref->pause_when_hidden = pauseWhenHidden();
@@ -464,7 +482,7 @@ void PrefGeneral::updateDriverCombos() {
 		}
 		else
 		if (vo == "null" || vo == "png" || vo == "jpeg" || vo == "gif89a" || 
-            vo == "tga" || vo == "pnm" || vo == "md5sum" ) 
+            vo == "tga" || vo == "pnm" || vo == "md5sum" || vo == "image" || vo == "tct") 
 		{
 			; // Nothing to do
 		}
@@ -672,6 +690,7 @@ QString PrefGeneral::subtitleLang() {
 	return subtitle_lang_edit->text();
 }
 
+#if SELECT_TRACKS_ON_STARTUP
 void PrefGeneral::setAudioTrack(int track) {
 	audio_track_spin->setValue(track);
 }
@@ -687,6 +706,7 @@ void PrefGeneral::setSubtitleTrack(int track) {
 int PrefGeneral::subtitleTrack() {
 	return subtitle_track_spin->value();
 }
+#endif
 
 void PrefGeneral::setCloseOnFinish(bool b) {
 	close_on_finish_check->setChecked(b);
@@ -1239,25 +1259,29 @@ void PrefGeneral::createHelp() {
 	addSectionTitle(tr("Preferred audio and subtitles"));
 
 	setWhatsThis(audio_lang_edit, tr("Preferred audio language"),
-		tr("Here you can type your preferred language for the audio streams. "
-           "When a media with multiple audio streams is found, SMPlayer will "
-           "try to use your preferred language.<br>"
-           "This only will work with media that offer info about the language "
-           "of the audio streams, like DVDs or mkv files.<br>"
-           "This field accepts regular expressions. Example: <b>es|esp|spa</b> "
+#if SIMPLE_TRACK_SELECTION
+		tr("You can specify here a priority list of audio language codes, separated by commas. "
+           "For example: spa,eng,jpn")
+
+#else
+		tr("This field accepts regular expressions. Example: <b>es|esp|spa</b> "
            "will select the audio track if it matches with <i>es</i>, "
-           "<i>esp</i> or <i>spa</i>.") );
+           "<i>esp</i> or <i>spa</i>.")
+#endif
+	);
 
 	setWhatsThis(subtitle_lang_edit, tr("Preferred subtitle language"),
-		tr("Here you can type your preferred language for the subtitle stream. "
-           "When a media with multiple subtitle streams is found, SMPlayer will "
-           "try to use your preferred language.<br>"
-           "This only will work with media that offer info about the language "
-           "of the subtitle streams, like DVDs or mkv files.<br>"
-           "This field accepts regular expressions. Example: <b>es|esp|spa</b> "
+#if SIMPLE_TRACK_SELECTION
+		tr("You can specify here a priority list of subtitle language codes, separated by commas. "
+           "For example: spa,eng,jpn")
+#else
+		tr("This field accepts regular expressions. Example: <b>es|esp|spa</b> "
            "will select the subtitle stream if it matches with <i>es</i>, "
-           "<i>esp</i> or <i>spa</i>.") );
+           "<i>esp</i> or <i>spa</i>.")
+#endif
+	);
 
+#if SELECT_TRACKS_ON_STARTUP
 	setWhatsThis(audio_track_spin, tr("Audio track"),
 		tr("Specifies the default audio track which will be used when playing "
            "new files. If the track doesn't exist, the first one will be used. "
@@ -1269,7 +1293,7 @@ void PrefGeneral::createHelp() {
            "playing new files. If the track doesn't exist, the first one "
            "will be used. <br><b>Note:</b> the <i>\"preferred subtitle "
            "language\"</i> has preference over this option.") );
-
+#endif
 }
 
 #include "moc_prefgeneral.cpp"
