@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@ PrefPlaylist::PrefPlaylist(QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 	retranslateStrings();
+
+#ifndef PLAYLIST_DELETE_FROM_DISK
+	allow_delete_files_check->hide();
+#endif
 }
 
 PrefPlaylist::~PrefPlaylist() {
@@ -155,6 +159,16 @@ bool PrefPlaylist::filterCaseSensitive() {
 	return case_sensitive_search_check->isChecked();
 }
 
+#ifdef PLAYLIST_DELETE_FROM_DISK
+void PrefPlaylist::allowDeleteFromDisk(bool b) {
+	allow_delete_files_check->setChecked(b);
+}
+
+bool PrefPlaylist::isDeleteFromDiskAllowed() {
+	return allow_delete_files_check->isChecked();
+}
+#endif
+
 void PrefPlaylist::createHelp() {
 	clearHelp();
 
@@ -200,6 +214,8 @@ void PrefPlaylist::createHelp() {
         "the file is actually played. Beware: this option can be slow, "
         "specially if you add many files."));
 
+	addSectionTitle(tr("Misc"));
+
 	setWhatsThis(autosort_check, tr("Auto sort"),
 		tr("If this option is enabled the list will be sorted automatically after adding files."));
 
@@ -210,6 +226,12 @@ void PrefPlaylist::createHelp() {
 		tr("If this option is checked, a copy of the playlist will be saved "
            "in the configuration file when SMPlayer is closed, and it will "
            "reloaded automatically when SMPlayer is run again."));
+
+#ifdef PLAYLIST_DELETE_FROM_DISK
+	setWhatsThis(allow_delete_files_check, tr("Enable the option to delete files from disk"),
+		tr("This option allows you to enable the option to delete files from disk in the playlist's "
+           "context menu. To prevent accidental deletions this option is disabled by default."));
+#endif
 }
 
 #include "moc_prefplaylist.cpp"
