@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,10 @@
 #include <QString>
 #include <QMap>
 
+#include "config.h"
+
+class QSettings;
+
 /* Class to store info about video/audio tracks */
 
 class TrackData {
@@ -91,7 +95,14 @@ public:
 	TrackData item(int ID);
 	int find(int ID);
 
+	int IDAt(int n);
+
+#if !SIMPLE_TRACK_SELECTION
 	int findLang(QString expr);
+#endif
+
+	void save(QSettings * set, const QString & name);
+	void load(QSettings * set, const QString & name);
 
 protected:
 	typedef QMap <int, TrackData> TrackMap;
